/*!
 * Ext Core Library 3.0
 * http://extjs.com/
 * Copyright(c) 2006-2009, Ext JS, LLC.
 * 
 * MIT Licensed - http://extjs.com/license/mit.txt
 */
#ux-lightbox {
    position: absolute;
    left: 0;
    width: 100%;
    z-index: 15000;
    text-align: center;
    line-height: 0;
}

#ux-lightbox img {
    width: auto;
    height: auto;
}

#ux-lightbox a img {
    border: none;
}

#ux-lightbox-outerImageContainer {
    position: relative;
    background-color: #f3efec;
    width: 250px;
    height: 250px;
    margin: 0 auto;
}

#ux-lightbox-imageContainer {
    padding: 10px;
}

#ux-lightbox-loading{
    position: absolute;
    top: 40%;
    left: 0%;
    height: 25%;
    width: 100%;
    text-align: center;
    line-height: 0;
    background: url(../images/lightbox/lb-load.gif) no-repeat center 15%;
}

#ux-lightbox-hoverNav {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    z-index: 10;
}

#ux-lightbox-imageContainer > #ux-lightbox-hoverNav {
    left: 0;
}

#ux-lightbox-hoverNav a{
    outline: none;
}

#ux-lightbox-navPrev,
#ux-lightbox-navNext {
    width: 49%;
    height: 100%;
    background-image: url(data:image/gif;base64,AAAA); /* Trick IE into showing hover */
    display: block;
}

#ux-lightbox-navPrev { left: 0; float: left;}
#ux-lightbox-navNext { right: 0; float: right;}
#ux-lightbox-navPrev:hover, #ux-lightbox-navPrev:visited:hover { background: url(../images/lightbox/lb-prev.png) left 33% no-repeat; }
#ux-lightbox-navNext:hover, #ux-lightbox-navNext:visited:hover { background: url(../images/lightbox/lb-next.png) right 33% no-repeat; }

#ux-lightbox-outerDataContainer {
    margin: 0 auto;
    width: 100%;
}

#ux-lightbox-dataContainer{
    font: 10px Verdana, Helvetica, sans-serif;
    background-color: #f3efec;
    overflow: auto;
    line-height: 1.4em;
}

#ux-lightbox-data{	padding:0 10px; color: #666; }
#ux-lightbox-data #ux-lightbox-details{ width: 80%; float: left; text-align: left; }
#ux-lightbox-data #ux-lightbox-caption{ font-weight: bold;	}
#ux-lightbox-data #ux-lightbox-imageNumber{ display: block; clear: left; padding-bottom: 1.0em;	}
#ux-lightbox-data #ux-lightbox-navClose{ background: url(../images/lightbox/lb-close.gif) no-repeat; width: 66px; height: 22px; float: right;  padding-bottom: 0.7em; outline: none;}
#ux-lightbox-data #ux-lightbox-navClose:hover{ background-image: url(../images/lightbox/lb-close-over.gif);}

#ux-lightbox-overlay,
#ux-lightbox-shim{
    border: 0;
    position: absolute;
    top: 0;
    left: 0;
    z-index: 14999;
    width: 100%;
    height: 500px;
    background-color: #000;
    padding: 0;
    margin: 0;
}

#ux-lightbox-shim {
    z-index: 89;
    background-color: transparent;
    filter: alpha(opacity=0);
}
